@@ -47,9 +47,7 @@ func newStatus() *cobra.Command {
 }
 
 func runMachineStatus(ctx context.Context) (err error) {
-	var (
-		io = iostreams.FromContext(ctx)
-	)
+	io := iostreams.FromContext(ctx)
 
 	var (
 		appName   = app.NameFromContext(ctx)
@@ -57,7 +55,6 @@ func runMachineStatus(ctx context.Context) (err error) {
 	)
 
 	app, err := appFromMachineOrName(ctx, machineID, appName)
-
 	if err != nil {
 		return err
 	}
@@ -90,15 +87,16 @@ func runMachineStatus(ctx context.Context) (err error) {
 			machine.Name,
 			machine.PrivateIP,
 			machine.Region,
-			fmt.Sprint(machine.Config.Guest.CPUs),
+			machine.Config.Metadata["process_group"],
 			fmt.Sprint(machine.Config.Guest.MemoryMB),
+			fmt.Sprint(machine.Config.Guest.CPUs),
 			machine.CreatedAt,
 			machine.UpdatedAt,
 			strings.Join(machine.Config.Init.Cmd, " "),
 		},
 	}
 
-	var cols []string = []string{"ID", "Instance ID", "State", "Image", "Name", "Private IP", "Region", "Memory", "CPUs", "Created", "Updated", "Command"}
+	var cols []string = []string{"ID", "Instance ID", "State", "Image", "Name", "Private IP", "Region", "Process Group", "Memory", "CPUs", "Created", "Updated", "Command"}
 
 	if len(machine.Config.Mounts) > 0 {
 		cols = append(cols, "Volume")
@@ -123,7 +121,7 @@ func runMachineStatus(ctx context.Context) (err error) {
 		if event.Request != nil && event.Request.ExitEvent != nil {
 			exitEvent := event.Request.ExitEvent
 			fields = append(fields, fmt.Sprintf("exit_code=%d,oom_killed=%t,requested_stop=%t",
-				exitEvent.GuestExitCode, exitEvent.OOMKilled, exitEvent.RequestedStop))
+				exitEvent.ExitCode, exitEvent.OOMKilled, exitEvent.RequestedStop))
 		}
 
 		eventLogs = append(eventLogs, fields)
